#
# spec file for package mozc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}

%if "%flavor" == "fcitx5"
%define with_fcitx4 0
%define with_fcitx5 1
%define install_mozc 0
%else
%define with_fcitx4 1
%define with_fcitx5 0
%define install_mozc 1
%endif

%if %{with_fcitx4}
%define fcitx_icon_dir %{_datadir}/fcitx/mozc/icon/
%define fcitx_addon_dir %{_datadir}/fcitx/addon/
%define fcitx_inputmethod_dir %{_datadir}/fcitx/inputmethod/
%define fcitx_lib_dir %{_libdir}/fcitx/
%endif

%if %{with_fcitx5}
%define fcitx5_addon_dir %{_datadir}/fcitx5/addon/
%define fcitx5_inputmethod_dir %{_datadir}/fcitx5/inputmethod/
%define fcitx5_lib_dir %{_libdir}/fcitx5/
%endif

%define server_dir %{_libdir}/mozc
%define ibus_mozc_path %{_libdir}/ibus-mozc/ibus-engine-mozc
%define ibus_mozc_icon_path %{_datadir}/ibus-mozc/mozc.png
%define document_dir %{_docdir}/ibus-mozc
%define use_libprotobuf 0
%define bz_cachdir %{_sourcedir}/BAZEL_CACHE
%define makebazelcache() mkdir -p %{bz_cachdir}/content_addressable/sha256/%{?2:%2}%{?!2:$(sha256sum %1 | cut -f 1 -d ' ')}/; cp %1 %{bz_cachdir}/content_addressable/sha256/%{?2:%2}%{?!2:$(sha256sum %1 | cut -f 1 -d ' ')}/file ;

Name:           mozc
Version:        2.29.5268.102
Release:        1.6
Summary:        Mozc - Japanese Input Method for Chromium OS, Mac and Linux
License:        Apache-2.0 AND BSD-3-Clause AND SUSE-Public-Domain
Group:          System/I18n/Japanese
ExcludeArch:    ppc ppc64 s390 s390x %{ix86}
URL:            https://github.com/google/mozc
# Run ./make_archive.sh to make tar.xz removing third party files
Source0:        %{name}-%{version}.tar.xz
Source1:        README.SUSE
Source4:        ibus-setup-mozc-jp.desktop.in
#
# svn export http://japanese-usage-dictionary.googlecode.com/svn/trunk/@r10
# japanese-usage-dictionary
# License: BSD-2-Clause
Source5:        japanese_usage_dictionary-r10.tar.xz
# protobuf (without third party code)
# License: BSD-3-Clause
#
# Bazel requires static protobuf
Source6:        https://github.com/protocolbuffers/protobuf/releases/download/v24.2/protobuf-24.2.tar.gz
# abseil cpp
# License: Apache-2.0
# https://github.com/abseil/abseil-cpp/archive/refs/tags/20230125.3.tar.gz
Source7:        abseil-cpp-20230125.3.tar.gz
#
# jigyosyo.zip and ken_all.zip are zip-code--address data provided by
# Japan Post Co., Ltd.
# License: SUSE-Public-Domain
# Run ./make_archive.sh to download the latest files
Source10:       jigyosyo.zip
Source11:       ken_all.zip
# material design icons
# License: Apache-2.0
Source12:       material-design-icons.tar.xz
#
# add fcitx as mozc module
# License: BSD-3-Clause
# https://github.com/fcitx/mozc/tree/fcitx/src/unix/fcitx{,5}
# Run ./make_archive.sh to make tar.xz
%if %{with_fcitx4} || %{with_fcitx5}
Source20:       fcitx-mozc-fdf25583.tar.xz
Source21:       fcitx-mozc-icons.tar.gz
Patch20:        fcitx-mozc-bazel-build.patch
%endif
#
# Protobuf dependencies
# protocolbuffers/bazel-rules-ruby
# License: Apache-2.0
# https://github.com/protocolbuffers/rules_ruby/archive/8fca842a3006c3d637114aba4f6bf9695bb3a432.zip
Source31:       bazel-rules-ruby-8fca842a.zip
# License: BSD-3-Clause
# https://github.com/protocolbuffers/upb/archive/ea4e825d22c9ae0031d59ec5e86dc85bb50cbbcb.zip
Source32:       upb-ea4e825d.zip
# License: MIT
# https://github.com/protocolbuffers/utf8_range/archive/de0b4a8ff9b5d4c98108bdfe723291a33c52c54f.zip
Source33:       utf8_range-de0b4a8f.zip

# A script for making a source tar.xz archive
Source100:      make_archive.sh
Source101:      add-sha256sum-for-zipcode-archives.patch.in

# PATCH-FEATURE-OPENSUSE ftake@geeko.jp
Patch1:         ibus-provide-layout-variations.patch
# PATCH-FIX-OPENSUSE fcitx5-mozc-fix.patch tiwai@suse.de -- Fix config of fcitx5-mozc
Patch9:         fcitx5-mozc-fix.patch
# PATCH-FIX-OPENSUSE add-sha256sum-for-zipcode-archives.patch ftake@geeko.jp -- to avoid download
# generated by ./make_archive.sh
Patch10:        add-sha256sum-for-zipcode-archives.patch
# PATCH-FIX-OPENSUSE support-python-3.6.patch ftake@geeko.jp -- Enable to build with Python 3.6
Patch11:        support-python-3.6.patch
# PATCH-FIX-UPSTREAM ibus-mozc-candidate-window-qt-virtual-coordinate.patch -- Fix Qt6 coordinate issue
Patch12:        ibus-mozc-candidate-window-qt-virtual-coordinate.patch

BuildRequires:  bazel-apple-support-source
BuildRequires:  bazel-rules-android-ndk-source
BuildRequires:  bazel-rules-apple-0_32-source
BuildRequires:  bazel-rules-cc-source
BuildRequires:  bazel-rules-java-source
BuildRequires:  bazel-rules-pkg-source
BuildRequires:  bazel-rules-proto-source
BuildRequires:  bazel-rules-python-source
BuildRequires:  bazel-rules-swift-source
BuildRequires:  bazel-skylib-source
BuildRequires:  bazel-workspaces
BuildRequires:  bazel6
%if 0%{?suse_version} == 1500
BuildRequires:  gcc10-c++
%endif
%if %{use_libprotobuf}
BuildRequires:  protobuf-devel
%endif
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Mozc is a Japanese Input Method Editor (IME) designed for
multi-platform such as Chromium OS, Mac and Linux. This open-source
project originates from Google Japanese Input.

%package -n ibus-mozc
Summary:        The Mozc engine for IBus
Group:          System/I18n/Japanese
BuildRequires:  ibus-devel
Requires:       ibus >= 1.4.1
Requires:       mozc = %{version}
Requires:       mozc-gui-tools = %{version}
Recommends:     ibus-mozc-candidate-window
Provides:       locale(ibus:ja)

%description -n ibus-mozc
The Mozc engine for IBus provides a Japanese input method.

%package -n ibus-mozc-candidate-window
Summary:        An optional candidate window for ibus-mozc
Group:          System/I18n/Japanese
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6Gui)
BuildRequires:  pkgconfig(Qt6Widgets)
Requires:       ibus-mozc = %{version}
Provides:       locale(ibus:ja)

%description -n ibus-mozc-candidate-window
This package provides an advanced candidate window for IBus. The
window shows examples of selected words.

%if %{with_fcitx4}
%package -n fcitx-mozc
Summary:        The Mozc backend for Fcitx
Group:          System/I18n/Japanese
BuildRequires:  fcitx-devel
Requires:       fcitx
Requires:       mozc = %{version}
Requires:       mozc-gui-tools = %{version}
Provides:       locale(fcitx:ja)

%description -n fcitx-mozc
The Mozc backend for Fcitx provides a Japanese input method.
%endif

%if %{with_fcitx5}
%package -n fcitx5-mozc
Summary:        The Mozc backend for Fcitx 5
Group:          System/I18n/Japanese
BuildRequires:  fcitx5-devel
Requires:       fcitx5
Requires:       mozc = %{version}
Requires:       mozc-gui-tools = %{version}
Provides:       locale(fcitx5:ja)

%description -n fcitx5-mozc
The Mozc backend for Fcitx 5 provides a Japanese input method.
%endif

%package gui-tools
Summary:        GUI tools for mozc
Group:          System/I18n/Japanese
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6Gui)
BuildRequires:  pkgconfig(Qt6Widgets)
Requires:       mozc = %{version}

%description gui-tools
This package provides config, word-register, dictioaly,
character-palette tools.

%prep
%setup -q

# extract fcitx-mozc
%if %{with_fcitx4} || %{with_fcitx5}
tar xvf %{SOURCE20}
%patch -P 20 -p1
%endif

%patch -P 1 -p1

cp %{SOURCE1} .

# install third_party files
cd src/third_party
# japanese_usage_dictionary
tar xvf %{SOURCE5}
# protobuf
%if ! %{use_libprotobuf}
mkdir protobuf
tar xvf %{SOURCE6} -C protobuf --strip-components 1
%endif
# abseil
mkdir abseil-cpp
tar xvf %{SOURCE7} -C abseil-cpp --strip-components 1
cd ../..

%if %{with_fcitx5}
%patch -P 9 -p1
%endif
%patch -P 10 -p1

%if 0%{?suse_version} == 1500
%patch -P 11 -p1
%endif

%patch -P 12 -p1

# fix installation, library and header path
sed -e 's|@libdir@|%{_libdir}|g' %{SOURCE4} > ibus-setup-mozc-jp.desktop

sed -i -e 's|^\(LINUX_MOZC_DOCUMENT_DIR = \).*|\1 "%{_docdir}/%{name}"|' src/config.bzl
sed -i -e 's|^\(LINUX_MOZC_SERVER_DIR = \).*|\1 "%{_libdir}/mozc"|' src/config.bzl
sed -i -e 's|^\(IBUS_MOZC_PATH = \).*|\1 "%{_libdir}/ibus-mozc/ibus-engine-mozc"|' src/config.bzl
sed -i -e 's|^\(IBUS_MOZC_ICON_PATH = \).*|\1 "%{ibus_mozc_icon_path}"|' src/config.bzl

echo build --override_repository="rules_python=/usr/src/bazel-rules-python" >> src/.bazelrc
echo build --override_repository="rules_cc=/usr/src/bazel-rules-cc" >> src/.bazelrc
echo build --override_repository="rules_java=/usr/src/bazel-rules-java" >> src/.bazelrc
echo build --override_repository="rules_proto=/usr/src/bazel-rules-proto" >> src/.bazelrc
echo build --override_repository="build_bazel_rules_apple=/usr/src/bazel-rules-apple-0_32" >> src/.bazelrc
echo build --override_repository="build_bazel_apple_support=/usr/src/bazel-apple-support" >> src/.bazelrc
echo build --override_repository="build_bazel_rules_swift=/usr/src/bazel-rules-swift" >> src/.bazelrc
echo build --override_repository="bazel_skylib=/usr/src/bazel-skylib" >> src/.bazelrc
echo build --override_repository="zlib=/usr/share/bazel-workspaces/zlib" >> src/.bazelrc
echo build --override_repository="rules_android_ndk=/usr/src/bazel-rules-android-ndk" >> src/.bazelrc
echo build --override_repository="rules_pkg=/usr/src/bazel-rules-pkg" >> src/.bazelrc

# set compile options from distribution
for f in %{optflags}; do
	case $f in
		*FORTIFY_SOURCE*) ;; # conflicts with opts (-DFORTIFY_SOURCE and -Werror) from source
		*) echo build --copt=$f >> src/.bazelrc
	esac
done

# prepare zip code dictionary
%makebazelcache %{SOURCE10}
%makebazelcache %{SOURCE11}
%makebazelcache %{SOURCE31}
%makebazelcache %{SOURCE32}
%makebazelcache %{SOURCE33}

# icons
tar xvf %{SOURCE12}
%makebazelcache material-design-icons/dictionary.png
%makebazelcache material-design-icons/dictionary.svg
%makebazelcache material-design-icons/properties.png
%makebazelcache material-design-icons/properties.svg
%makebazelcache material-design-icons/tool.png
%makebazelcache material-design-icons/tool.svg

%build

cd src

%if 0%{?suse_version} == 1500
export CC=gcc-10
export CXX=g++-10
%endif

# Be careful bazel cache is not cleared by `obs build`
# --output_base might help

bazel build package \
%if %{with_fcitx4}
	"//unix/fcitx:fcitx-mozc.so" \
%endif
%if %{with_fcitx5}
	"//unix/fcitx5:fcitx5-mozc.so" \
%endif
	--repository_cache=%{bz_cachdir} \
	--config oss_linux \
	-c opt \
	--force_pic \
	%{?jobs:--jobs %{jobs}} \
	--strip=never \
	--sandbox_debug \
	--verbose_failures \
	-s

bazel shutdown

%define output_dir src/bazel-bin

%if %{with_fcitx4}
cd unix/fcitx
./gen_fcitx_mozc_i18n.sh ../../../%{output_dir}/unix/fcitx/po
%endif
%if %{with_fcitx5}
cd unix/fcitx5
../fcitx/gen_fcitx_mozc_i18n.sh ../../../%{output_dir}/unix/fcitx5/po
%endif

%install

%if %{install_mozc}
install -m755 -d %{buildroot}%{_libdir}/ibus-mozc
install -m755 %{output_dir}/unix/ibus/ibus_mozc %{buildroot}%{_libdir}/ibus-mozc/ibus-engine-mozc
install -m755 -d %{buildroot}%{_datadir}/ibus/component
install -m644 %{output_dir}/unix/ibus/mozc.xml %{buildroot}%{_datadir}/ibus/component/mozc.xml
install -m755 -d %{buildroot}%{_datadir}/ibus-mozc
unzip %{output_dir}/unix/icons.zip -d %{buildroot}%{_datadir}/ibus-mozc/

install -m755 -d %{buildroot}%{_datadir}/applications
install -m644 ibus-setup-mozc-jp.desktop %{buildroot}%{_datadir}/applications/ibus-setup-mozc-jp.desktop
%suse_update_desktop_file ibus-setup-mozc-jp System X-SuSE-Core-System

# for provide-layout-variations patch
ln -s ibus-setup-mozc-jp.desktop %{buildroot}%{_datadir}/applications/ibus-setup-mozc-jp-jp.desktop
%suse_update_desktop_file ibus-setup-mozc-jp-jp System X-SuSE-Core-System
ln -s ibus-setup-mozc-jp.desktop %{buildroot}%{_datadir}/applications/ibus-setup-mozc-us.desktop
%suse_update_desktop_file ibus-setup-mozc-us System X-SuSE-Core-System
ln -s ibus-setup-mozc-jp.desktop %{buildroot}%{_datadir}/applications/ibus-setup-mozc-dv.desktop
%suse_update_desktop_file ibus-setup-mozc-dv System X-SuSE-Core-System
%endif

%if %{with_fcitx4}
# Install Fcitx module
for mofile in %{output_dir}/unix/fcitx/po/*.mo
do
	filename=`basename $mofile`
	lang=${filename/.mo/}
	install -D -m 644 "$mofile" "%{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES/fcitx-mozc.mo"
done
install -m755 -d %{buildroot}%{fcitx_addon_dir}
install -m755 -d %{buildroot}%{fcitx_inputmethod_dir}
install -m755 -d %{buildroot}%{fcitx_icon_dir}
install -m755 -d %{buildroot}%{fcitx_lib_dir}
install -m 755 %{output_dir}/unix/fcitx/fcitx-mozc.so %{buildroot}%{fcitx_lib_dir}/fcitx-mozc.so
install -m 644 src/unix/fcitx/fcitx-mozc.conf %{buildroot}%{fcitx_addon_dir}
install -m 644 src/unix/fcitx/mozc.conf %{buildroot}%{fcitx_inputmethod_dir}
install -m 644 src/data/images/product_icon_32bpp-128.png %{buildroot}%{fcitx_icon_dir}/mozc.png
install -m 644 src/data/images/unix/ui-alpha_full.png %{buildroot}%{fcitx_icon_dir}/mozc-alpha_full.png
install -m 644 src/data/images/unix/ui-alpha_half.png %{buildroot}%{fcitx_icon_dir}/mozc-alpha_half.png
install -m 644 src/data/images/unix/ui-direct.png %{buildroot}%{fcitx_icon_dir}/mozc-direct.png
install -m 644 src/data/images/unix/ui-hiragana.png %{buildroot}%{fcitx_icon_dir}/mozc-hiragana.png
install -m 644 src/data/images/unix/ui-katakana_full.png %{buildroot}%{fcitx_icon_dir}/mozc-katakana_full.png
install -m 644 src/data/images/unix/ui-katakana_half.png %{buildroot}%{fcitx_icon_dir}/mozc-katakana_half.png
install -m 644 src/data/images/unix/ui-dictionary.png %{buildroot}%{fcitx_icon_dir}/mozc-dictionary.png
install -m 644 src/data/images/unix/ui-properties.png %{buildroot}%{fcitx_icon_dir}/mozc-properties.png
install -m 644 src/data/images/unix/ui-tool.png %{buildroot}%{fcitx_icon_dir}/mozc-tool.png

# fix mozc icons. they're too ugly that even lose face for openSUSE.
cp -r %{SOURCE21} ./
tar -xzf fcitx-mozc-icons.tar.gz
cp -r fcitx-mozc-icons/* %{buildroot}%{fcitx_icon_dir}/
rm -rf fcitx-mozc-icons
rm -rf fcitx-mozc-icons.tar.gz
%endif

%if %{with_fcitx5}
# Install Fcitx5 module
for mofile in %{output_dir}/unix/fcitx5/po/*.mo
do
	filename=`basename $mofile`
	lang=${filename/.mo/}
	install -D -m 644 "$mofile" "%{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES/fcitx5-mozc.mo"
done
install -m755 -d %{buildroot}%{fcitx5_addon_dir}
install -m755 -d %{buildroot}%{fcitx5_inputmethod_dir}
install -m755 -d %{buildroot}%{fcitx5_lib_dir}
install -m 755 %{output_dir}/unix/fcitx5/fcitx5-mozc.so %{buildroot}%{fcitx5_lib_dir}/mozc.so
install -m 644 src/unix/fcitx5/mozc-addon.conf %{buildroot}%{fcitx5_addon_dir}/mozc.conf
install -m 644 src/unix/fcitx5/mozc.conf %{buildroot}%{fcitx5_inputmethod_dir}

unzip -d icons %{output_dir}/unix/icons.zip
install -D -m 644 src/data/images/product_icon_32bpp-128.png "%{buildroot}%{_datadir}/icons/hicolor/128x128/apps/org.fcitx.Fcitx5.fcitx-mozc.png"
install -D -m 644 src/data/images/unix/ime_product_icon_opensource-32.png "%{buildroot}%{_datadir}/icons/hicolor/32x32/apps/org.fcitx.Fcitx5.fcitx-mozc.png"
install -D -m 644 icons/mozc.svg "%{buildroot}%{_datadir}/icons/hicolor/scalable/apps/org.fcitx.Fcitx5.fcitx-mozc.svg"
install -D -m 644 icons/alpha_full.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/org.fcitx.Fcitx5.fcitx-mozc-alpha-full.png"
install -D -m 644 icons/alpha_half.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/org.fcitx.Fcitx5.fcitx-mozc-alpha-half.png"
install -D -m 644 icons/direct.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/org.fcitx.Fcitx5.fcitx-mozc-direct.png"
install -D -m 644 icons/hiragana.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/org.fcitx.Fcitx5.fcitx-mozc-hiragana.png"
install -D -m 644 icons/katakana_full.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/org.fcitx.Fcitx5.fcitx-mozc-katakana-full.png"
install -D -m 644 icons/katakana_half.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/org.fcitx.Fcitx5.fcitx-mozc-katakana-half.png"
install -D -m 644 icons/dictionary.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/org.fcitx.Fcitx5.fcitx-mozc-dictionary.png"
install -D -m 644 icons/properties.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/org.fcitx.Fcitx5.fcitx-mozc-properties.png"
install -D -m 644 icons/tool.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/org.fcitx.Fcitx5.fcitx-mozc-tool.png"

ln -sf org.fcitx.Fcitx5.fcitx-mozc.png "%{buildroot}%{_datadir}/icons/hicolor/128x128/apps/fcitx-mozc.png"
ln -sf org.fcitx.Fcitx5.fcitx-mozc.png "%{buildroot}%{_datadir}/icons/hicolor/32x32/apps/fcitx-mozc.png"
ln -sf org.fcitx.Fcitx5.fcitx-mozc.svg "%{buildroot}%{_datadir}/icons/hicolor/scalable/apps/fcitx-mozc.svg"
ln -sf org.fcitx.Fcitx5.fcitx-mozc-alpha-full.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/fcitx-mozc-alpha-full.png"
ln -sf org.fcitx.Fcitx5.fcitx-mozc-alpha-half.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/fcitx-mozc-alpha-half.png"
ln -sf org.fcitx.Fcitx5.fcitx-mozc-direct.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/fcitx-mozc-direct.png"
ln -sf org.fcitx.Fcitx5.fcitx-mozc-hiragana.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/fcitx-mozc-hiragana.png"
ln -sf org.fcitx.Fcitx5.fcitx-mozc-katakana-full.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/fcitx-mozc-katakana-full.png"
ln -sf org.fcitx.Fcitx5.fcitx-mozc-katakana-half.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/fcitx-mozc-katakana-half.png"
ln -sf org.fcitx.Fcitx5.fcitx-mozc-dictionary.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/fcitx-mozc-dictionary.png"
ln -sf org.fcitx.Fcitx5.fcitx-mozc-properties.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/fcitx-mozc-properties.png"
ln -sf org.fcitx.Fcitx5.fcitx-mozc-tool.png "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/fcitx-mozc-tool.png"

%endif

%if %{install_mozc}
install -m755 -d %{buildroot}%{server_dir}
install -m755 %{output_dir}/server/mozc_server %{buildroot}%{server_dir}
install -m755 %{output_dir}/gui/tool/mozc_tool %{buildroot}%{server_dir}
install -m755 %{output_dir}/renderer/qt/mozc_renderer %{buildroot}%{server_dir}

install -m755 -d %{buildroot}%{_bindir}
install -m755 %{output_dir}/unix/emacs/mozc_emacs_helper %{buildroot}%{_bindir}
# install only for emacs since xemacs is not supported
install -m755 -d %{buildroot}%{_datadir}/emacs/site-lisp
install -m644 src/unix/emacs/mozc.el %{buildroot}%{_datadir}/emacs/site-lisp/

chmod 644 src/data/installer/credits_*.html
%endif

%if %{with_fcitx4}
%find_lang fcitx-mozc %no_lang_C
%endif

%if %{with_fcitx5}
%find_lang fcitx5-mozc %no_lang_C
%endif

%if %{install_mozc}
%files
%defattr(-, root, root)
%doc src/data/installer/credits_en.html
%doc README.SUSE
%dir %{server_dir}
%{server_dir}/mozc_server
%{_bindir}/mozc_emacs_helper
%dir %{_datadir}/emacs/site-lisp/
%{_datadir}/emacs/site-lisp/mozc.el

%files gui-tools
%defattr(-, root, root)
%{_libdir}/mozc/mozc_tool

%files -n ibus-mozc
%defattr(-, root, root)
%license material-design-icons/LICENSE-material-design-icons
%dir %{_libdir}/ibus-mozc/
%{_libdir}/ibus-mozc/ibus-engine-mozc
%{_datadir}/applications/ibus-setup-mozc-jp.desktop
%{_datadir}/applications/ibus-setup-mozc-jp-jp.desktop
%{_datadir}/applications/ibus-setup-mozc-us.desktop
%{_datadir}/applications/ibus-setup-mozc-dv.desktop
%dir %{_datadir}/ibus/component/
%{_datadir}/ibus/component/mozc.xml
%{_datadir}/ibus-mozc/

%files -n ibus-mozc-candidate-window
%defattr(-, root, root)
%{_libdir}/mozc/mozc_renderer
%endif

%if %{with_fcitx4}
%files -n fcitx-mozc -f fcitx-mozc.lang
%defattr(-,root,root)

%{fcitx_lib_dir}/fcitx-mozc.so
%{fcitx_addon_dir}/fcitx-mozc.conf
%dir %{fcitx_inputmethod_dir}
%{fcitx_inputmethod_dir}/mozc.conf
%dir %{_datadir}/fcitx/mozc
%dir %{fcitx_icon_dir}
%{fcitx_icon_dir}/mozc.png
%{fcitx_icon_dir}/mozc-alpha_full.png
%{fcitx_icon_dir}/mozc-alpha_half.png
%{fcitx_icon_dir}/mozc-direct.png
%{fcitx_icon_dir}/mozc-hiragana.png
%{fcitx_icon_dir}/mozc-katakana_full.png
%{fcitx_icon_dir}/mozc-katakana_half.png
%{fcitx_icon_dir}/mozc-dictionary.png
%{fcitx_icon_dir}/mozc-properties.png
%{fcitx_icon_dir}/mozc-tool.png
%endif

%if %{with_fcitx5}
%files -n fcitx5-mozc -f fcitx5-mozc.lang
%defattr(-,root,root)

%{fcitx5_lib_dir}/mozc.so
%{fcitx5_addon_dir}/mozc.conf
%dir %{fcitx5_inputmethod_dir}
%{fcitx5_inputmethod_dir}/mozc.conf
%{_datadir}/icons/hicolor/
%endif

%changelog
* Sat Feb 24 2024 Fuminobu Takeyama <ftake@geeko.jp> - 2.29.5268.102
- Upstream update to 2.29.5268
  * Update dictionaries
  * Fix crash issue of the candidate window UI
- Update zip code dictionaries
  * Refresh add-sha256sum-for-zipcode-archives.patch
- Add patch ibus-mozc-candidate-window-qt-virtual-coordinate.patch
  * Fix google #823: candidate window position issue on HiDPI displays
- Enable to build with Python 3.6
  * Add support-python-3.6.patch
* Fri Feb 23 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Sun Sep 10 2023 Fuminobu Takeyama <ftake@geeko.jp> - 2.29.5220.102
- Upstream update to 2.29.5220.102
  * Update the segment prefix for Tabi
  * Update dictionaries
  * Switch to Qt6
  * Update protobuf to 24.2
- Update fcitx-mozc
- Update zip code dictionaries
  * Refresh add-sha256sum-for-zipcode-archives.patch
  - Update hash codes
  - Add a comment to state auto generated
- Fix the compiler options from RPM is not passed to a compiler
* Wed Aug 16 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Fix build without %%jobs
* Sat Jun 10 2023 Fuminobu Takeyama <ftake@geeko.jp> - 2.29.5111.102
- Upstream update to 2.29.5111.102
  * Fix overlay of mozc-candidate-style in mozc.el
  * Enable the candidate window to show on a secondary and later display
  * Update dictionaries
  * Introduce MOZC_IBUS_CANDIDATE_WINDOW to disable mozc_renderer
  * Support Emoji 15.0
  * Support ImeOn/ImeOff keys
  * Update absel-cpp and protobuf
  * Remove add-missing-include.patch
  - Merged by upstream
- Update fcitx-mozc
  * Refresh fcitx-mozc-bazel-build.patch
- Update zip code dictionaries
  * Refresh add-sha256sum-for-zipcode-archives.patch
* Fri Apr 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add add-missing-include.patch: Add missing #include <cstdint>,
  fix build with gcc13.
- Rebase patches with quilt.
* Thu May  5 2022 Fuminobu Takeyama <ftake@geeko.jp> - 2.28.4715.102
- Upstream update to 2.28.4715.102
  * Update dictionaries
  * Enable Qt candidate window on Wayland session
- Update fcitx5-mozc
  * Improve system tray menus
- Fix fcitx5-mozc cannot find icons
- Use icons from Mozc for Fcitx5 since their quality is now
  improved
- Update postcode dictionaries
- Refresh add-sha256sum-for-zipcode-archives.patch
- Refresh fcitx-mozc-bazel-build.patch
- Fix icon path in ibus-setup-mozc-jp.desktop
* Tue Apr  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Exclude build on i586: bazel is not supported on i586, thus we
  have no build system available for mozc.
* Sat Feb 26 2022 Fuminobu Takeyama <ftake@geeko.jp>
- Upstream update to 2.26.4660.102
  * Fix the description of half-width tilde
  * New feature to customize the initial input mode
  * Qt5 based candidate window (renderer)
  * Add larger size PNG and SVG icons
  * Fixed issues on the Emacs client #421, #497
- Update Fcitx4/5 mozc to the latest
- Add Fcitx5 mo files
- Update README.SUSE
- Switch the build system to Bazel
- Update bundled protobuf to v3.19.3 lined statically
- Update abseil-cpp to 20211102.0
- Add icons from material-design-icons
- Add fcitx-mozc-bazel-build.patch
- Use gcc8 for Leap 15 because <filesystem> is now required
- Drop patches due to build system change
  * mozc-ninja-verbose-build.patch
  * mozc-build-gcc.patch
  * build-with-libstdc++.patch
- Add add-sha256sum-for-zipcode-archives.patch
  * to allow offline build
- Drop ibus-qt5-hide_preedit_text-workaround.patch
  * fixed in Qt side
* Sun Feb 13 2022 tiwai@suse.de
- Remove /usr/share/pixmaps from filelist of fcitx5-mozc as zypper
  complains the conflict with filesystems
* Sat Feb 12 2022 tiwai@suse.de
- Enable fcitx5 build with _muiltibuild, as fcitx5 is included now
  in FACTORY
* Tue Nov 23 2021 tiwai@suse.de
- Move mozc-fcitx5.spec to a dedicated linked package (for now)
* Mon Nov 22 2021 tiwai@suse.de
- Add python3-six to BuildReq explicitly, as the implicit
  dependency chain was broken on TW
* Wed Nov 10 2021 tiwai@suse.de
- Add fcitx5-mozc support: fcitx5-mozc-fix.patch
  It could be done with multibuild once when fcitx5 landed in
  FACTORY, but as of now, it's built in a separate spec file.
* Mon Feb  8 2021 Fuminobu Takeyama <ftake@geeko.jp>
- Upstream update to 2.26.4276.102
  * Fix problem with conversion including a number
  * Introduce a new configuration file ibus_config.textproto
    so that users can change IBus keyboard layout without root
- Update README.SUSE
- Update post code dictionary
- Update abseil-cpp to 20200923.3
- Refresh build-with-libstdc++.patch
- Refresh ibus-provide-layout-variations.patch
- Remove fcitx-mozc-2.23.2815.102.1.patch
  * Replaced with fcitx-mozc.tar.xz
- Remove fcitx-fix-for-a1dcadab.patch
  * Merged by upstream
* Thu Nov  5 2020 Fuminobu Takeyama <ftake@geeko.jp>
- Upstream update to 2.25.4150
  * Remove hand writing feature by using Zinnia
  * Update dictionaries
  * Python 3 Support
  * No changelog is available
- Add abseil-cpp
- Remove mozc-gen_zip_code_seed_py.patch
  * Fix spec file so that the tool works without this patch
- Remove patches merged by upstream
  * gcc-8.1-ZeroQueryDict-iterator.patch
  * add-Japanese-new-era-reiwa-to-dict.patch
  * add-Japanese-new-era-reiwa-to-date_rewriter.patch
  * add-Japanese-new-era-reiwa-ligature-to-dict.patch
  * mozc-2.23.2815.102-protobuf_generated_classes_no_inheritance.patch
  * build-scripts-migration-to-python3.patch
  * fix-zip-code-conversion-output.patch
- Add build-with-libstdc++.patch
  * Force to use libstdc++ instead of libc++
- Add fcitx-fix-for-a1dcadab.patch
  * Fix fcitx-mozc patch for the latest mozc
- Refresh mozc-ninja-verbose-build.patch
- Update make_archive.sh
* Thu Sep 10 2020 Fuminobu Takeyama <ftake@geeko.jp>
- Build scripts migration to Python 3
  * Add: build-scripts-migration-to-python3.patch
  * Add: fix-zip-code-conversion-output.patch
- Update post code dictionary
* Sat Sep  5 2020 Fuminobu Takeyama <ftake@geeko.jp>
- Use system libprotobuf because Mozc's build script cannot handle
  newer protobuf source code
  * Fix build error under RISC V environment
  * Add: mozc-2.23.2815.102-protobuf_generated_classes_no_inheritance.patch
* Wed May 27 2020 Fuminobu Takeyama <ftake@geeko.jp>
- Remove third party files which are not distributed BSD-3-Clause
  from the source tar.xz
* Mon Apr 20 2020 Cliff Zhao <qzhao@suse.com>
- Update mozc.spec: Drop the is_opensuse macro to eliminate in
  behavior in between SLE-15 and openSUSE Leap (jsc#SLE-11737).
* Sun Feb  2 2020 Fuminobu Takeyama <ftake@geeko.jp>
- Upstream update to 2.23.2815
  * Do not use mozc_renderer on Wayland session
  * Support GYP_DEFINES='enable_gtk_renderer=0'
  * Migrate from IBusConfig to GSetting in ibus_mozc
  * Update dictionary
  * Code refactoring
- Update zip code dictionary to Jan. 2020
- Update gyp
  * to the version ready for Python 3
- Update protobuf to 3.5.2
- Update Fcitx Mozc
  * Remove: fcitx-mozc-2.18.2612.102.1.patch
  * Add: fcitx-mozc-2.23.2815.102.1.patch
- Refresh patches
  * add-Japanese-new-era-reiwa-to-date_rewriter.patch
  * add-Japanese-new-era-reiwa-to-dict.patch
* Fri Apr 12 2019 ftake@geeko.jp
- update to support the Japanese new era, Reiwa (boo#1132450)
  * add-Japanese-new-era-reiwa-ligature-to-dict.patch
  * add-Japanese-new-era-reiwa-to-date_rewriter.patch
  * add-Japanese-new-era-reiwa-to-dict.patch
- update zip code dictionary
* Tue Jul 24 2018 ftake@geeko.jp
- add gcc-8.1-ZeroQueryDict-iterator.patch
  * fix a build error with gcc 8
* Sun Mar 25 2018 ro@suse.de
- add excludearch for ppc/ppc64/s390/s390x as the code assumes
  little endian all over the place (bsc#1086763)
* Sun Dec  4 2016 i@marguerite.su
- update 2.18.2612.102
  * fixed unexpected size bloat of the APK
  * fixed duplicate candidates after undo
  * fixed suggestion-only user dictionary entry may not work
  * fixed abbreviation user dictionary entry may not work
  * fixed suppression word may not work
  * fixed single character noun user dictionary entry may not work
- fcitx-mozc updated to 2.18.2612.102
  * dropped patch: fcitx-mozc-2.17.2102.102.1.patch
  * added patch: fcitx-mozc-2.18.2612.102.1.patch
- protobuf updated to 3.1.0
  * dropped patch: protobuf-atomic.patch, upstreamed
  * dropped patch: protobuf-generic-atomic.patch, upstreamed
- gyp updated to latest master@940a15e
- added patch: mozc-gen_zip_code_seed_py.patch
* Tue Aug 23 2016 mgorse@suse.com
- Disable fcitx on SLE again.
* Tue Aug  2 2016 ftake@geeko.jp
- fix unnecessary "BuildRequires: protobuf-devel"
* Fri Jul 29 2016 normand@linux.vnet.ibm.com
- remove ExcludeArch as related failure caused by workaround
- remove workaround https://llvm.org/bugs/show_bug.cgi?id=22248
  in spec as now using gcc not clang.
  remove mozc-stack-protector.patch
* Wed Jul 27 2016 qzhao@suse.com
- Add mozc-build-gcc.patch, Force mozc build with gcc(g++).
  Exclude PPC, PPC64, PPC64LE and AARCH64 build target.(bsc#990844)
* Sat Jul  2 2016 ftake@geeko.jp
- Update Japanese zip code / address table (June 2016)
* Tue Mar  8 2016 ftake@geeko.jp
- Upstream update to 2.17.2313.102
  * "-j" option is deprecated
  * Calculator supports inputs starting with "="
  * ibus-mozc supports "icon_prop_key" and input mode labels are
    shown on tray icon
  * Minor updates and refactoring
- Update ibus-provide-layout-variations.patch
- Update mozc-ninja-verbose-build.patch
* Fri Oct  9 2015 liujianfeng1994@gmail.com
- Upstream update to 2.17.2123.102
  * Update system dictionary
  * Support rule-based zero query suggestion in 2.16.2080.102
  * GYP repository is switched from code.google.com to chromium.googlesource.com
  * Fix: ibus predict window is shown at the previous cursor position
  * Fix: Preedit and candidate changes buffer modification flag
  * Fix a typo
  * Fix: Possible build failure due to missing dependency on commands_proto from key_info_util
  * Fix: ibus-mozc should enable undo-commit if and only if IBUS_CAP_SURROUNDING_TEXT is set
  * ibus-mozc no longer tries to align suggestion window to the left edge of the composing text
- add fcitx-mozc-2.17.2102.102.1.patch
- remove fcitx-mozc-2.16.2037.102.2.patch
- Specify GYP_DEFINES="use_libzinnia=1" to link to system-installed Zinnia
* Tue Sep 22 2015 ftake@geeko.jp
- Fix ibus-mozc does not allow to remove tha last character
  of preedit text on Qt5 application
  * workaround for the Qt5 bug (boo#947013)
  * Add ibus-qt5-hide_preedit_text-workaround.patch
* Mon Aug 17 2015 dvaleev@suse.com
- Enable PowerPC builds.
  * Add generic atomics on Power (protobuf-generic-atomic.patch ,
    protobuf-atomic.patch)
  * Workaround llvm bug https://llvm.org/bugs/show_bug.cgi?id=22248
    (mozc-stack-protector.patch)
* Thu Aug 13 2015 normand@linux.vnet.ibm.com
- ExcludeArch ppc ppc64 ppc64le because no support in
  third_party/protobuf/src/google/protobuf/stubs/ atomicops
* Sun Jun 28 2015 i@marguerite.su
- add fcitx-mozc-2.16.2037.102.2.patch
- add mozc-ninja-verbose-build.patch
- update gyp 20150628
- use-libprotobuf=0 for internal protobuf to workaround system
  one's symbol undefined errors caused by gcc-5
* Wed Mar  4 2015 liujianfeng1994@gmail.com
- Upstream update to 2.16.2037.102
  * Fix: Inconsistency between suggestion candidates and conversion candidates
  * add llvm-clang as build dependence
* Thu Jan 22 2015 liujianfeng1994@gmail.com
- Upstream update to 2.16.2020.102
  * Fix Noisy candidate "itsumo" due to language aware conversion
  * Fix AssertionError in gen_zip_code_seed.py
* Sun Dec 28 2014 liujianfeng1994@gmail.com
- Upstream update to 2.16.2003.102
  * Updated main dictionary, Emoji dictionary, emoticon dictionary, and single kanji dictionary
  * Fix IME crashes when using US International hardware keyboard
  * Fix ibus-mozc + XIM: preedit text is not cleared after preedit commit triggered by focus change
  * Fix An empty word can be suggested in the candidate list
- Remove boo906143-revert-session.patch: Merged by upstream
- Update gyp to r2012
* Thu Dec 18 2014 ftake@geeko.jp
- Add boo906143-revert-session.patch
  * Fix pre-edit is not reset after focus lost (boo#906143)
* Mon Dec  1 2014 liujianfeng1994@gmail.com
- Upstream update to 1.15.1917.102
  * Fix Warning message from keymap editor should be updated
- Upstream update to 1.15.1895.102
  * Fix Partial suggestion for numbers are not annotated by <部分確定>
* Sun Aug 31 2014 ftake@geeko.jp
- Upstream update to 1.15.1868.102
  * Fix 'Set input mode to X' commands do not work
    during "Direct Input" mode
- Upstream update to 1.15.1856.102
  * Several internal changes and changes for other platforms
- Upstream update to 1.15.1834.102
  * Use Ninja for building
- Upstream update to 1.15.1814.102
  * Fix wring key mapping for Numpad-End in mozc.el
  * Fix dropping candidats unexpectedly
  * Fix preceding text is not correctly extracted by ibus-mozc
  * Fix undo-commit (MS IME keybind) is not functional in ibus-mozc
- Update fcitx-mozc
- Update gyp to r1957
* Thu Jun 12 2014 ftake@geeko.jp
- Upstream update to 1.15.1785.102
  * Change fcitx-mozc-1.13.1651.102.1.patch to a tar.bz2 archive
  * Fix wrong event handling in emacs-mozc and improve LEIM support
- Drop fix-initial-input-mode.patch
  * merged by upstream
* Fri Jan 10 2014 ftake@geeko.jp
- Enable the zip-code dictionary feature
* Wed Jan  8 2014 ftake@geeko.jp
- Upstream update to 1.13.1651.102
  * Refactor placeholder management
  * Fix specify _NET_WM_WINDOW_TYPE to mozc_renderer
  * Fix header-line-format breaks candidate window on Emacs 24
- Upstream update to 1.12.1599.102
  * Fix Wrong conversion caused by number rewriter
  * Reduce the file size of connection.txt
  * Fix a crash issue in keyevent handling at mozc.el
  * Remove Chromium OS specific code from ibus-mozc
  * Support gyp r1667 and later
  * Support IBus 1.5.4
  * Update dictionary
  * Support Adobe Reader and Adobe Flash running under protected mode on Windows
  * Extend "did you mean" feature as pseudo direct mode
- Update fcitx-mozc
- Drop support-input-purpose.patch
  * merged by upstream
- Refresh patches
  * ibus-provide-layout-variations.patch
  * fix-initial-input-mode.patch
- Update gyp to r1829
* Mon Oct 28 2013 ftake@geeko.jp
- Fix typed password is shown on GNOME lock screen bnc#847718
  * Add support-input-purpose.patch
- Fix config button is disabled on GNOME Control Center rh#904625
- Change initial input mode of ibus-mozc to direct input Issue#201
  * Add fix-initial-input-mode.patch
- Enables keyboard layout variations for ibus-mozc
  * Add ibus-provide-layout-variations.patch
  * Supplements the fix above
* Sun Sep  1 2013 ftake@geeko.jp
- Upstream update to 1.11.1522.102
  * Enable to customize ibus-mozc
  * Add session command for ConvertPrevPage and ConvertNextPage
- Update fcitx-mozc
  * Support usage of conversion candidates
  * Support paging
- Add a source archive of gyp removed from the Mozc tree
- Clean up the spec file
* Sun Jul 21 2013 ftake@geeko.jp
- Upstream update to 1.11.1502.102
  * Fixes cursor movement issue on Emacs 24
  * Support numpad keys in mozc.el
  * Support GCC 4.8.0
  * Fix build failure when use_libprotobuf=1 is specified
  * Support Emacs 24 in mozc.el
  * Support surrounding text
  * Enable to configure document directory and/or Zinnia model file path
  * Update dictionary
- Update fcitx-mozc
  * Add Germany translation
- Drop patches merged by upstream
  * mozc-gcc48.patch
  * fix-use_libprotobuf.patch
* Tue Jun 25 2013 pgajdos@suse.com
- fixed build with gcc 4.8
  * mozc-gcc48.patch
* Sun Apr 14 2013 ftake@geeko.jp
- upstream update to 1.10.1390.102
  * mozc_renderer now checks physycal monitor area
  * add missing properties for gnome-shell
- update fcitx-mozc
  * bug fixes and usability improvement
  * new patch: fix-use_libprotobuf.patch
    absolute path of protobuf, or mozc can't recognize
* Thu Mar 28 2013 i@marguerite.su
- fix fcitx mozc icons.
  * Defaults look too ugly that even lose face for openSUSE.
* Sat Jan 12 2013 ftake@geeko.jp
- update fcitx-mozc patch to 1.6.1187.102.3
  * The license of the patch is changed to BSD-3-Clause (bnc#797954)
  * Note: the license of Fcitx have exception that add-ons of Fcitx
    need not obey GPL
  * update translation
  * update key translate
* Thu Jan 10 2013 jengelh@inai.de
- Wrap description at 70 cols
- Remove unnecessary ldconfig call for fcitx-mozc (it is a plugin
  without any SONAME links)
* Wed Jan  9 2013 ftake@geeko.jp
- add provides locale to make ibus-mozc and fcitx-mozc default
  packages for Japanese
* Wed Dec 19 2012 ftake@geeko.jp
- clean up the spec file
- add Recommends ibus-mozc-candidate-window
* Sat Sep  1 2012 ftake@geeko.jp
- update to version 1.6.1187.102
  * scim_mozc is removed
  * 'Preference' button is added on the setup dialog of IBus
  * minor updates and refactoring
* Mon Jun  4 2012 ftake@geeko.jp
- activate mozc_renderer and add new package ibus-mozc-candidate-window
- remove unneeded BuildRequires
* Sun Jun  3 2012 i@marguerite.su
- update to version 1.5.1090.102
  * Add a workaround against QTBUG-25536 ( Issue 158 )
  * 'mozc_renderer' on Linux (a.k.a. 'gtk_renderer') ( Issue 145 ):
  * Experimental option (--enable_gtk_renderer) has been deprecated
    and 'mozc_renderer' is now enabled by default on Linux.
    You can still remove the dependencies to mozc_renderer as follows.
    GYP_DEFINES=enable_gtk_renderer=0 python build_mozc.py gyp
* Mon May  7 2012 i@marguerite.su
- update to version 1.5.1053.102
  * 'libcurl4-openssl-dev' is replaced with 'libssl-dev' in the build
    dependencies on Linux.
  * 'emacs-mozc' now works correctly even when the Homonym dictionary is
    enabled.  ( Issue 146 )
  * 'mozc_renderer' on Linux (a.k.a. 'gtk_renderer') (Issue 145):
  - 'libgtk2.0-dev' is now required to build 'mozc_renderer' on Linux.
  - 'ibus-mozc' now checks if 'mozc_renderer' exists along with 'mozc_server'
    or not. If 'mozc_renderer' does not exist, 'ibus-mozc' behaves as if
  - -enable_gtk_renderer was not specified.
  - Now 'mozc_renderer' can be built with GLib >=2.31.0.
  - Now 'mozc_renderer' automatically adjusts its window location on the edge
    of the display.
  - Now 'mozc_renderer' uses custom font settings of IBus-panel if available.
  - The position of candidate window no longer be disturbed by some background
    applications such as GNU Emacs23, which periodically issue
    set_cursor_position message even when they are background.
  - Now 'ibus-mozc' uses IBus candidate window if the application does not
    have the capability to show preedit string such as Emacs23 or xterm.
* Tue Apr 24 2012 ftake@geeko.jp
- clean up the spec file
- remove an unnecessary patch
* Tue Apr 17 2012 i@marguerite.su
- Upstream update (1.4.1033.102)
  * supports Hiragana and Katakana key
  * mozc.el supports PageUp and PageDown key
- add fcitx im framework support.
  * %%if %%{with_fcitx} makes it conditional.
* Sun Mar 11 2012 ftake@geeko.jp
- Upstream update (1.4.1003.102)
  * support IBus 1.4.1
  * fix some minor bugs
* Thu Feb 23 2012 ftake@geeko.jp
- Upstream update (1.3.975.102)
  * fix bug IME_ON/OFF are not displayed on a key map window
  * fix crash bugs triggered by commit
* Wed Dec 21 2011 ftake@geeko.jp
- Upstream update (1.3.930.102)
  * fix memory leak in scim-mozc
  * fix bugs of reconversion
* Thu Dec  1 2011 ftake@geeko.jp
- Upstream update (1.3.911.102)
  * New: undo, reconversion for IBus
  * improve the menus on IBus language bar
  * change ibus-mozc rank to 80; mozc can be preloaded by default
  * fix Eisu toggle key issue for emacs
  * fix crash problem on scim
* Tue Aug 23 2011 ftake@geeko.jp
- Upstream update
  * New: romaji spelling correction
  * New: search feature in the dictionary tool
  * fixed some minor bugs
- Removed build dependency on "gtest".
* Thu Jul 28 2011 ftake@geeko.jp
- Packaged an emacs macro and separated gui tools into a subpackage
* Thu Jul 21 2011 ftake@geeko.jp
- Upstream update (1.1.773.102)
* Thu Jul  7 2011 ftake@geeko.jp
- Initial import
  * Upstream version: 1.1.758
  * I refered to kazukado's and xkitty68's packages.
